@@ -102,7 +102,7 @@ class BaseEvent(URIModel):
 
     person = models.ForeignKey('coop_local.Person', null=True, blank=True, verbose_name=_('author'))
     if "coop_geo" in settings.INSTALLED_APPS:
-        location = models.ForeignKey('coop_geo.Location', null=True, blank=True, verbose_name=_('location'))
+        location = models.ForeignKey('coop_local.Location', null=True, blank=True, verbose_name=_('location'))
         remote_location_uri = models.URLField(_('remote location URI'), blank=True, max_length=255)
         remote_location_label = models.CharField(_(u'remote location label'),
                                                 max_length=250, blank=True, null=True,
@@ -218,7 +218,12 @@ class BaseEvent(URIModel):
 
 
     def article_mapping(self, rdfPred, djF, datatype=None, lang=None):
-        return self.multi_mapping(rdfPred, djF, datatype, lang)
+        if getattr(self, djF) == None:
+            return [] 
+        else:
+            values = getattr(self, djF)
+            return self.multi_mapping_base(values, rdfPred, datatype, lang)
+
 
     def article_mapping_reverse(self, g, rdfPred, djField, lang=None):
         articles = list(g.objects(rdflib.term.URIRef(self.uri), rdfPred))
