@@ -30,8 +30,8 @@ if "coop_cms" in settings.INSTALLED_APPS:
                                                     max_length=250, blank=True, null=True,
                                                     help_text=_(u'fill this only if the organization record is not available locally'))
 
-        isSection = models.BooleanField(_(u'is section'), default=False, 
-                                        help_text=_(u"Afficher les articles de niveau inférieur dans l'arborescence"))
+        isSection = models.BooleanField(_(u'Container article'), default=False, 
+                                        help_text=_(u"Will display a list of links for its children articles"))
 
 
         if "coop.agenda" in settings.INSTALLED_APPS:
@@ -56,7 +56,7 @@ if "coop_cms" in settings.INSTALLED_APPS:
 
         # RDF stuff
         def isOpenData(self):
-            return not self.isSection
+            return not self.isSection and self.publication == BaseArticle.PUBLISHED
 
         rdf_type = settings.NS.dcmi.Text
         base_mapping = [
