@@ -5,6 +5,7 @@ from coop_local.models import *
 from coop.person.admin import PersonAdmin
 from coop.org.admin import OrganizationAdmin
 from coop.prefs.admin import SitePrefsAdmin
+from coop_geo.admin import LocationAdmin, AreaAdmin
 from django.conf import settings
 
 # -- Loading base models
@@ -18,7 +19,18 @@ admin.site.register(Organization, OrganizationAdmin)
 admin.site.register(OrganizationCategory)
 admin.site.register(OrgRelationType)
 admin.site.register(SitePrefs, SitePrefsAdmin)
+admin.site.register(Location, LocationAdmin)
+admin.site.register(Area, AreaAdmin)
 
+if "coop.project" in settings.INSTALLED_APPS:
+    from coop.project.admin import ProjectAdmin
+    admin.site.register(Project, ProjectAdmin)
+    admin.site.register(ProjectCategory)
+
+if "coop.mailing" in settings.INSTALLED_APPS:
+    from coop.mailing.admin import MailingListAdmin, NewsletterAdmin
+    admin.site.register(MailingList, MailingListAdmin)
+    admin.site.register(Newsletter, NewsletterAdmin)
 
 if "coop.exchange" in settings.INSTALLED_APPS:
     from coop.exchange.admin import ExchangeAdmin
@@ -35,7 +47,7 @@ if "coop_cms" in settings.INSTALLED_APPS:
 if "coop_tag" in settings.INSTALLED_APPS:
     from coop_tag.settings import get_class
     admin.site.unregister(get_class('tag'))
-    admin.site.register(get_class('tag'))  # et ???
+    admin.site.register(get_class('tag'))  # TODO find out why this hack has to be there !!!
 
 if 'forms_builder.forms' in settings.INSTALLED_APPS:
     from coop.admin import CoopFormAdmin
