@@ -1,11 +1,15 @@
 # -*- coding:utf-8 -*-
-
 import os
 from coop_local.settings import PROJECT_PATH, PROJECT_NAME
 
 TIME_ZONE = 'Europe/Paris'
 LANGUAGE_CODE = 'fr-FR'
-SITE_ID = 1
+
+from multisite import SiteID
+SITE_ID = SiteID(default=1)
+COOP_USE_SITES = False
+
+
 USE_I18N = True
 USE_L10N = True
 
@@ -43,11 +47,13 @@ STATICFILES_FINDERS = [
 #    'django.contrib.staticfiles.finders.DefaultStorageFinder',
 ]
 
+
 TEMPLATE_DIRS = [
     os.path.abspath(PROJECT_PATH + '/coop_local/templates/')
 ]
 
 TEMPLATE_LOADERS = [
+    'multisite.template_loader.Loader',
     'django.template.loaders.filesystem.Loader',
     'django.template.loaders.app_directories.Loader',
 #     'django.template.loaders.eggs.Loader',
@@ -63,6 +69,7 @@ MIDDLEWARE_CLASSES = [
     #'django.middleware.cache.FetchFromCacheMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'multisite.middleware.DynamicSiteMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
     #'django_webid.auth.middleware.WEBIDAuthMiddleware',
     'django.middleware.clickjacking.XFrameOptionsMiddleware',
@@ -89,6 +96,8 @@ ROOT_URLCONF = 'coop_local.urls'
 # Python dotted path to the WSGI application used by Django's runserver.
 WSGI_APPLICATION = 'coop_local.wsgi.application'
 
+CACHE_MULTISITE_ALIAS = 'multisite'
+
 # Cache middelware must be enabled above
 CACHES = {
     'default': {
@@ -98,6 +107,10 @@ CACHES = {
         'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
         #'LOCATION': '127.0.0.1:11211',
         'LOCATION': 'unix:/tmp/memcached.sock',
+    },
+    'multisite': {
+        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+        'TIMEOUT': 60 * 60 * 24,  # 24 hours
     }
 }
 
@@ -106,6 +119,12 @@ CACHE_MIDDLEWARE_SECONDS = 60 * 60
 CACHE_MIDDLEWARE_KEY_PREFIX = PROJECT_NAME
 
 
+# The view function or class-based view that django-multisite will
+# use when it cannot match the hostname with a Site. This can be
+# the name of the function or the function itself.
+# Default: None
+MULTISITE_FALLBACK = 'django.views.generic.base.RedirectView'
+
 INSTALLED_APPS = [
 
     # admin tools
@@ -126,13 +145,15 @@ INSTALLED_APPS = [
     #'django.contrib.admindocs', # ramène sa traduction de Tags "Étiquettes"...
     'django.contrib.gis',
     'django.contrib.comments',
+    # 'djgeojson',
 
     # other 3rd parties
     'south',
     'django_extensions',
     'extended_choices',
     'floppyforms',
-    #'haystack',
+    # 'haystack',
+    # 'haystack_fr',
     #'oembed',
     'chosen',
     'sorl.thumbnail',
@@ -143,6 +164,7 @@ INSTALLED_APPS = [
     'preferences',
     'apptemplates',
     'scanredirect',
+    'multisite',
 
 
     # WebID
@@ -159,7 +181,7 @@ INSTALLED_APPS = [
     'coop.org',
     'coop.person',
     'coop.ui',
-    #'coop.webid',
+    'coop.rdf',
 
     'coop_geo',
 
@@ -190,6 +212,7 @@ TAGGER_TAGGEDITEM_MODEL = 'coop_local.models.TaggedItem'
 TAGGER_FKEY_NAME = 'coop_local.Tag'
 
 THUMBNAIL_FORMAT = 'PNG'
+ADMIN_THUMBS_SIZE = '60x60'
 
 TINYMCE_DEFAULT_CONFIG = {
     'theme': "advanced",
@@ -200,6 +223,8 @@ TINYMCE_DEFAULT_CONFIG = {
     'theme_advanced_buttons2': '', 'theme_advanced_buttons3': ''
     }
 
+COOP_NEWLETTER_ITEM_CLASSES = ['article']
+
 COOP_CMS_ARTICLE_CLASS = 'coop_local.models.Article'
 COOP_CMS_ARTICLE_FORM = 'coop.forms.ArticleForm'
 COOP_CMS_ARTICLE_LOGO_SIZE = '600'
@@ -336,15 +361,15 @@ LOGGING = {
             'handlers': ['console'],
             'propagate': False,
         },
-        'subhub.maintenance': {
-            'handlers': ['console'],
-            'level': 'ERROR'
-        },
-        'subhub.distribution.process': {
-            'handlers': ['console'],
-            'level': 'ERROR'
+        # 'subhub.maintenance': {
+        #     'handlers': ['console'],
+        #     'level': 'ERROR'
+        # },
+        # 'subhub.distribution.process': {
+        #     'handlers': ['console'],
+        #     'level': 'ERROR'
 
-        },
+        # },
         'worker': {
             'handlers': ['console'],
             'level': 'DEBUG'
@@ -352,7 +377,7 @@ LOGGING = {
         },
         'coop': {
             'handlers': ['console-dumb'],
-            'level': 'ERROR',
+            'level': 'DEBUG',
         },
     },
 
