@@ -11,11 +11,19 @@ try:
     try:
         _server = WSDL.Proxy(sympa_soap['WSDL'])
     except Exception, e:
+        _server = None
         logger.warning(u"Cannot find find Sympa server - %s" % e)
 except ImportError:
     raise ImproperlyConfigured("coop.mailing is installed but we need SYMPA_SOAP settings.")
 
 
+
+def sympa_available():
+    if _server: 
+        return True
+    return False
+
+
 def lists():
     try:
         return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
@@ -29,14 +37,18 @@ def lists():
 
 def info(name):
     try:
-        return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
-                                                    sympa_soap['PASSWORD'],
-                                                    'USER_EMAIL=' + sympa_soap['OWNER'],
-                                                    'info',
-                                                    (name,)
-                                                    )
+        if _server:
+            return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
+                                                        sympa_soap['PASSWORD'],
+                                                        'USER_EMAIL=' + sympa_soap['OWNER'],
+                                                        'info',
+                                                        (name,)
+                                                        )
+        else:
+            return 'Unknown list'
     except faultType, e:
-        return e.faultstring
+        logger.warning(e.faultstring)
+        return 'Unknown list'
 
 
 def exists(name):
@@ -49,12 +61,15 @@ def exists(name):
 
 def create_list(name, subject, template, description, topics=u'topics'):
     try:
-        return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
-                                                    sympa_soap['PASSWORD'],
-                                                    'USER_EMAIL=' + sympa_soap['OWNER'],
-                                                    'createList',
-                                                    (name, subject, template, description, topics)
-                                                    )
+        if _server:
+            return _server.authenticateRemoteAppAndRun(sympa_soap['APPNAME'],
+                                                        sympa_soap['PASSWORD'],
+                                                        'USER_EMAIL=' + sympa_soap['OWNER'],
+                                                        'createList',
+                                                        (name, subject, template, description, topics)
+                                                        )
+        else:
+            return 'Server not defined'
     except faultType, e:
         return e.faultstring
 
