@@ -14,6 +14,11 @@ class Command(TemplateCommand):
             "given directory.")
 
     option_list = TemplateCommand.option_list + (
+
+        make_option('--haystack',
+                    action='store_true', dest='haystack', default=False,
+                    help=_(u'Set the value to 1 to have Haystack available (default is 0)')),
+
         make_option('--redis_port',
                     action='store', dest='redis', default=6379,
                     help=_(u'Please set the redis port the application will used (default value is 6379')),
@@ -58,6 +63,12 @@ class Command(TemplateCommand):
         options['extensions'].extend(['conf', 'json', 'txt'])
         options['virtualenv'] = os.getenv('VIRTUAL_ENV')
         options['nice_name'] = project_name.title()
+
+        if options["domain"] != "localhost:8000":
+            options["root_domain"] = (".").join(options["domain"].split(".")[1:])
+        else:
+            options["root_domain"] = options["domain"]
+
         p = os.popen('which runinenv.sh', "r")
         options['runinenv'] = p.readline().replace('\n', '')
         p.close()
