@@ -10,6 +10,7 @@ import shortuuid
 from rdflib import Graph, plugin, Literal, URIRef, BNode
 from django.contrib.contenttypes import generic
 from django.contrib.sites.models import Site
+from django.contrib.sites.managers import CurrentSiteManager
 from django.db import IntegrityError
 from django.template import Template, Context
 from urlparse import urlsplit
@@ -22,6 +23,10 @@ import datetime
 from subhub.models import DistributionTask
 from django.core.validators import URLValidator
 from django.core.exceptions import ValidationError
+import logging
+import urllib
+
+log = logging.getLogger('coop')
 
 
 
@@ -46,6 +51,7 @@ plugin.register('trix', plugin.Serializer,
 
 
 
+
 class TimestampedModel(models.Model):
     created = exfields.CreationDateTimeField(_(u'created'), null=True)
     modified = exfields.ModificationDateTimeField(_(u'modified'), null=True)
@@ -54,16 +60,27 @@ class TimestampedModel(models.Model):
         abstract = True
 
 
+def select_with_lang(literals, lang=None):
+    res = []
+    for l in literals:
+        if l.language == lang:
+            res.append(l)
+    return res
+
+
 def get_urimode_from_uri(uri):
     scheme, host, path, query, fragment = urlsplit(uri)
-    if host == Site.objects.get_current().domain:
+    if host == Site.objects.get(id=1).domain  or host == Site.objects.get_current().domain:
         return URI_MODE.LOCAL
-    elif host in ['rdf.insee.fr', 'ns.economie-solidaire.fr', 'data.economie-solidaire.fr']:
+    elif host in ['rdf.insee.fr', 'ns.economie-solidaire.fr', 'thess.economie-solidaire.fr']:
         return URI_MODE.COMMON
     else:
         return URI_MODE.IMPORTED
 
 
+
+
+
 class StaticURIModel(models.Model):
     """
     To use this model as a basis for your own abstract model, you need to have
@@ -96,10 +113,15 @@ class StaticURIModel(models.Model):
 
     # La version simple c'est de passer par le save() et de supprimer le default.... c'est pas
     # tres beau, car un plus couteux en runtime... mais bon
-    uuid = models.CharField(_(u'uuid'), max_length=50, null=True, editable=False, unique=True, default=shortuuid.uuid)
+    uuid = models.CharField(_(u'uuid'), max_length=50, null=True, editable=False, default=shortuuid.uuid)
 
     links = generic.GenericRelation('coop_local.Link', related_name="%(app_label)s_%(class)s_related")
 
+    # to handle multi site possibility
+    sites = models.ManyToManyField(Site)
+    objects_manager = models.Manager()  # take care of the order, the admin uses the first manager found
+    objects = CurrentSiteManager()
+
     # the default value, this attribut should be overloaded
     domain_name = None
 
@@ -122,8 +144,9 @@ class StaticURIModel(models.Model):
     def uri_registry(self):
         return self.__class__.__name__.lower()
 
+    # be careful in case of multi domain. Uri are localted to the FIRST domain, supposed to be the principal
     def init_uri(self):
-        return u"http://%s/id/%s/%s/" % (self.domain_name or str(Site.objects.get_current().domain),
+        return u"http://%s/id/%s/%s/" % (self.domain_name or str(Site.objects.get(id=1).domain),
                                          self.uri_registry(),
                                          unicode(self.uri_id)  # can be anything = int, uuid, unicode...
                                         )
@@ -153,7 +176,7 @@ class StaticURIModel(models.Model):
 
 
     # try to translate an rdflib object in a django object
-    # return None if it fails
+    # return None if it fails; This method does NOT create any instance
     # Bnode are not yet handled.... but it has to be done for the futur
     @staticmethod
     def toDjango(term):
@@ -169,7 +192,7 @@ class StaticURIModel(models.Model):
             scheme, host, path, query, fragment = urlsplit(uri)
             if host == 'rdf.insee.fr':
                 # Area de INSEE
-                m = models.get_model('coop_geo', 'area')
+                m = models.get_model('coop_local', 'area')
                 try:
                     return m.objects.get(uri=uri)
                 except m.DoesNotExist:
@@ -181,24 +204,33 @@ class StaticURIModel(models.Model):
                     return m.objects.get(uri=uri)
                 except m.DoesNotExist:
                     return None
-            elif host == 'data.economie-solidaire.fr':
+            elif host == 'thess.economie-solidaire.fr':
                 # Role Category
-                m = models.get_model('coop_local', 'rolecategory')
+                m_role_category = models.get_model('coop_local', 'rolecategory')
                 try:
-                    return m.objects.get(uri=uri)
-                except m.DoesNotExist:
-                    pass  # les roles et les tags seront donc traités dans le code qui suit
+                    return m_role_category.objects.get(uri=uri)
+                except m_role_category.DoesNotExist:
+                    m_role = models.get_model('coop_local', 'role')
+                    try:
+                        return m_role.objects.get(uri=uri)
+                    except m_role.DoesNotExist:
+                        m_tag = models.get_model('coop_local', 'tag')
+                        try:
+                            return m_tag.objects.get(uri=uri)
+                        except m_tag.DoesNotExist:
+                            return None
             # Les normaux ...
             # BIG WARNING : it is supporded that uri dont change and match the model nam
             mName = path.split('/')[2]
             m = models.get_model('coop_local', mName)
-            if m == None:
-                m = models.get_model('coop_geo', mName)
+            # if m == None:
+            #     m = models.get_model('coop_geo', mName)
             if not m == None:
                 try:
                     return m.objects.get(uri=uri)
                 except m.DoesNotExist:
                     return None
+                    # return m.get_or_create_from_rdf(uri)  # trop tôt !
             else:
                 return None
 
@@ -209,6 +241,7 @@ class StaticURIModel(models.Model):
         return self.base_mapping + self.extra_mapping
 
     def base_single_mapping(self, uri, rdfPredicate, djangoField, datatype=None, lang=None):
+        validate = URLValidator()
         value = getattr(self, djangoField)
         if value == None:
             return []
@@ -220,7 +253,12 @@ class StaticURIModel(models.Model):
                 else:
                     rdfValue = None
             elif isinstance(self._meta.get_field(djangoField), models.URLField):
-                rdfValue = URIRef(value)
+                # let's protect rdf data...
+                try:
+                    validate(value)
+                    rdfValue = URIRef(value)
+                except ValidationError:
+                    rdfValue = None
             else:
                 subject_args = {}
                 if lang:
@@ -274,6 +312,10 @@ class StaticURIModel(models.Model):
             return self.multi_mapping_base(values, rdfPredicate, datatype, lang)
 
 
+    def none_reverse(self,  g, values, rdfPredicate, datatype=None, lang=None):
+        pass
+
+
     def base_single_reverse(self, uri, g, rdfPred, djField, datatype=None, lang=None, empty_value=None):
         value = list(g.objects(URIRef(uri(self)), rdfPred))
         if len(value) == 1:
@@ -285,10 +327,7 @@ class StaticURIModel(models.Model):
         elif len(value) == 0:
             setattr(self, djField, empty_value)
         else:  # plusieurs valeurs ca peut etre une histore de language
-            fr_value = []
-            for v in value:
-                if not v.language == None and v.language == lang:
-                    fr_value.append(v)
+            fr_value = select_with_lang(value, lang)
             if len(fr_value) == 1:
                 setattr(self, djField, unicode(fr_value[0]))
 
@@ -298,18 +337,48 @@ class StaticURIModel(models.Model):
         self.base_single_reverse(uri, g, rdfPred, djField, datatype, lang)
 
 
+    # TODO et les label
     def local_or_remote_reverse(self, g, rdfPred, djField, datatype=None, lang=None):
         uri = lambda x: x.uri
         # lets try the local version
         self.base_single_reverse(uri, g, rdfPred, djField, datatype, lang)
         if not getattr(self, djField):
             self.base_single_reverse(uri, g, rdfPred, 'remote_' + djField + '_uri', datatype, lang, empty_value=u'')
+            # to get the label... it is more complicated
+            value = list(g.objects(URIRef(uri(self)), rdfPred))
+            if len(value) == 1:
+                value = value[0]    # Should be an URIRef
+                if isinstance(value, URIRef):
+                    # Il faut parsser sur la PES a cause des roles 
+                    g_value = Graph()
+                    imp_uri = "%s/get_rdf/?url=%s" % (settings.PES_HOST, urllib.quote_plus(unicode(value).encode('utf-8')))
+                    g_value.parse(imp_uri, format='json-ld')
+                    labels = list(g_value.objects(value, settings.NS.rdfs.label))
+                    labels = set(select_with_lang(labels, lang))
+                    if len(labels) > 0:
+                        label = labels.pop()  # On suppose tres fort qu'il y en qu'un
+                    else:
+                        # lets try skos:prefLabel
+                        labels = list(g_value.objects(value, settings.NS.skos.prefLabel))
+                        labels = set(select_with_lang(labels, lang))
+                        if len(labels) > 0:
+                            label = labels.pop()
+                        else:
+                            label = u""
+                    setattr(self, 'remote_' + djField + '_label', unicode(label))
+                else:
+                    pass
+            else:  # I dont know what to do
+                pass
 
 
     def multi_reverse(self, g, rdfPred, djField, datatype=None, lang=None):
         manager = getattr(self, djField)
         rdf_values = set(g.objects(URIRef(self.uri), rdfPred))
         values = set(map(StaticURIModel.toDjango, rdf_values))
+        # if toDango return None for every rdf_valuesthen the set must be emty
+        if None in values:
+            values.remove(None)   
         old_values = set(manager.all())
         remove = old_values.difference(values)
         add = values.difference(old_values)
@@ -346,9 +415,13 @@ class StaticURIModel(models.Model):
             graph.parse(uri)  # RDFLib rules !!!!
         if not exists:
             instance = cls(uri=uri, uri_mode=get_urimode_from_uri(uri))
+            # a save is necessary, instance need to have a pk
+            # before calling import_rdf_data
+            instance.save()  
         else:
             instance = cls.objects.get(uri=uri)
         instance.import_rdf_data(graph)
+        return (instance, not exists)
 
 
     def import_rdf_data(self, g):
@@ -356,7 +429,7 @@ class StaticURIModel(models.Model):
             if hasattr(self, reverse):
                 getattr(self, reverse)(g, *arguments)
         from coop_local.models import Link, LinkProperty
-         # TODO possible optimisation: Do not remove all links, 
+        # TODO possible optimisation: Do not remove all links, 
         # check the diffence between new and old values as in previous multi_reverse fonction
         for l in self.links.all():
             self.links.remove(l)
@@ -369,9 +442,6 @@ class StaticURIModel(models.Model):
 
 
 
-
-
-    # Old version using d2rq
     def toRdf(self, format):
         """
            format correspond to the standard rdflib format keyword,
@@ -499,136 +569,11 @@ class StaticURIModel(models.Model):
 
 
 
-    # @classmethod
-    # def getD2rqGraph(cls):
-    #     context = {}
-    #     context['mapping_template'] = 'd2r/' + cls.__name__.lower() + '.ttl'
-    #     context['namespaces'] = settings.RDF_NAMESPACES
-
-    #     tmpfile = os.path.dirname(os.path.abspath(coop.__file__)) + '/templates/d2r/model.ttl'
-    #     f = open(tmpfile, 'r')
-    #     t = Template(f.read())
-    #     f.close()
-    #     res = t.render(Context(context))
-    #     (fd, fname) = tempfile.mkstemp()
-    #     f = open(fname, 'w')
-    #     f.write(res)
-    #     f.close()
-    #     graph = Graph()
-    #     graph.parse('file:' + fname, format='n3')
-    #     return graph
-
-    # @classmethod
-    # def updateFromFeeds(cls):
-    #     print "Update feed for class name %s" % cls.__name__
-    #     feed_url = settings.PES_HOST + 'feed/' + cls.__name__.lower() + '/'
-    #     parsedFeed = feedparser.parse(feed_url)
-    #     print "Parse feed %s" % feed_url
-    #     for entry in parsedFeed.entries:
-    #         print "Entry summary is %s " % entry.summary
-    #         fd, fname = tempfile.mkstemp()
-    #         os.write(fd, entry.summary)
-    #         os.close(fd)
-    #         g = Graph()
-    #         g.parse(fname, format="json-ld")
-    #         cls.updateFromGraph(g)
-
-
-    # @classmethod
-    # def updateFromGraph(cls, g):
-    #     done = set()
-    #     for subj in g.subjects(None, None):
-    #         if not (subj in done):
-    #             instance = cls.objects.get(uri=str(subj))
-    #             if not instance:
-    #                 print "Nothing to do with uri %s. Not found in database" % subj
-    #             else:
-    #                 instance.updateFromRdf(g)
-    #             done.add(subj)
-
-    # # Old version with d2R
-    # # The "reverse mapping is done here"
-    # def updateFromRdf(self, graph):
-    #     # Before reversing mapping, we have to check that the uri has not been
-    #     # changed. This the case for URI_MODE.IMPORTED instance which still point to
-    #     # the old uri
-
-    #     replacedBy = list(graph.objects(URIRef(self.uri), settings.NS.dct.isReplacedBy))
-    #     if self.uri_mode == URI_MODE.IMPORTED and len(replacedBy) == 1:
-    #         print "Handle rehost imported uri"
-    #         g = Graph()
-    #         g.parse(replacedBy[0])
-    #         self.uri = replacedBy[0]
-    #         self.updateFromRdf(g)
-    #     else:
-    #         db_table = self.__class__._meta.db_table
-    #         d2rqGraph = self.__class__.getD2rqGraph()
-    #         for field in self._meta.fields:
-    #             dbfieldname = db_table + '.' + field.name
-    #             pred = checkDirectMap(dbfieldname, d2rqGraph)
-    #             if pred:
-    #                 update = list(graph.objects(URIRef(self.uri), pred))
-    #                 if len(update) > 1:
-    #                     print "    The field %s cannot be updated. Too many values" % dbfieldname
-    #                 elif len(update) == 0:
-    #                     print "Nothing to update for field %s" % dbfieldname
-    #                 else:
-    #                     print "For id %s update the field %s" % (self.id, dbfieldname)
-    #                     update = update[0]
-    #                     # Well some field have to be prepared
-    #                     if isinstance(field, models.fields.DateField):
-    #                         update = update.split('.')[0]
-    #                         try:
-    #                             tt = time.strptime(update, "%Y-%m-%dT%H:%M:%S")
-    #                         except ValueError:
-    #                             tt = time.strptime(update, "%Y-%m-%d")
-    #                         update = "%d-%d-%d" % (tt.tm_year, tt.tm_mon, tt.tm_mday)
-    #                     setattr(self, field.name, update)
-    #             elif isinstance(field, models.ForeignKey):
-    #                 print "try an FKEY"
-    #                 pred = checkDirectMapFK(dbfieldname, d2rqGraph)
-    #                 if pred:
-    #                     self.updateFKfromRdf(field, dbfieldname, pred, graph)
-    #                 else:
-    #                     print "    The field %s cannot be updated." % dbfieldname
-
-    #             else:
-    #                  # See org/models file to have example of "special" fiels handling
-    #                 if hasattr(self, 'updateField_' + field.name):
-    #                     getattr(self, 'updateField_' + field.name)(dbfieldname, graph)
-    #                 else:
-    #                     print "    The field %s cannot be updated." % dbfieldname
-    #         print "UpdateFromRdf all fields have been handled"
-    #         self.save()
-    #         print "save done"
-
-
-    # def updateFKfromRdf(self, field, dbfieldname, pred, graph):
-    #     rdfObj = list(graph.objects(URIRef(self.uri), pred))
-    #     if len(rdfObj) == 1:
-    #         rdfObj = rdfObj[0]
-    #         print "FK object found %s" % rdfObj
-    #         if isinstance(rdfObj, URIRef):
-    #             try:
-    #                 obj = field.related.parent_model.objects.get(uri=str(rdfObj))
-    #                 setattr(self, field.name + '_id', obj.id)
-    #                 print "For id %s update the field %s" % (self.id, dbfieldname)
-    #             except ObjectDoesNotExist:
-    #                 # TODO: Object not found in db.... here we have to check il it
-    #                 # has to be imported or not.
-    #                 print "Obj not in bd : %s" % rdfObj
-    #                 print u"    The field %s cannot be updated." % dbfieldname
-    #         else:
-    #             print "    The field %s cannot be updated." % dbfieldname
-    #     else:
-    #         print "    The field %s cannot be updated." % dbfieldname
-
-    #     pass
 
 
     # This a very simple case, where feed and ub share the same host
     def subscribeToUpdades(self, host=settings.PES_HOST):
-        feed_url = "http://%s/feed/%s/%s/" % (host, self.__class__.__name__.lower(), self.uri_id)
+        feed_url = "%s/feed/%s/%s/" % (host, self.__class__.__name__.lower(), self.uri_id)
         validate = URLValidator(verify_exists=True)
         try:
             subs = Subscription.objects.get(topic=feed_url)
@@ -637,20 +582,20 @@ class StaticURIModel(models.Model):
         if not subs or (subs.lease_expiration and subs.lease_expiration < datetime.datetime.now() + datetime.timedelta(days=10)):   
             try:
                 validate(feed_url)
-                # print u"Try to subscribe to feed %s" % feed_url
-                Subscription.objects.subscribe(feed_url, hub="http://%s/hub/" % host)
+                # log.debug(u"Try to subscribe to feed %s" % feed_url)
+                Subscription.objects.subscribe(feed_url, hub="%s/hub/" % host)
             except ValidationError, e:
-                print u" Imposible to subscribe to %s : %s" % (feed_url, e)
+                log.debug(u" Impossible to subscribe to %s : %s" % (feed_url, e))
 
 
     def unsubscribeToUpdades(self, host=settings.PES_HOST):
-        feed_url = "http://%s/feed/%s/%s/" % (host, self.__class__.__name__.lower(), self.uri_id)
+        feed_url = "%s/feed/%s/%s/" % (host, self.__class__.__name__.lower(), self.uri_id)
         validate = URLValidator(verify_exists=True)
         try:
             validate(feed_url)
-            Subscription.objects.unsubscribe(feed_url, hub="http://%s/hub/" % host)
+            Subscription.objects.unsubscribe(feed_url, hub="%s/hub/" % host)
         except ValidationError, e:
-            print u" Imposible to unsubscribe to %s : %s" % (feed_url, e)
+            log.debug(u" Impossible to unsubscribe to %s : %s" % (feed_url, e))
 
 
 class URIModel(StaticURIModel, TimestampedModel):
@@ -658,48 +603,6 @@ class URIModel(StaticURIModel, TimestampedModel):
         abstract = True
 
 
-# def checkDirectMap(dbfieldName, d2rqGraph):
-#     lit = Literal(dbfieldName)
-#     subj = list(d2rqGraph.subjects(settings.NS.d2rq.column, lit))
-#     if len(subj) != 1:
-#         subj = list(d2rqGraph.subjects(settings.NS.d2rq.uriColumn, lit))
-#         if len(subj) != 1:
-#             return None
-#     subj = subj[0]
-#     prop = list(d2rqGraph.objects(subj, settings.NS.d2rq.property))
-#     if len(prop) != 1:
-#         return None
-#     else:
-#         return prop[0]
-
-
-# def checkDirectMapFK(dbfieldName, d2rqGraph):
-#     # on commence par chercher tous les triples de la forme
-#     # select * where { ?s d2rq:join ?l. filter(?l contains dbfieldname) }
-#     # mais comme le d2rqGraph n'est pas un SparqlGraph on le fait à la main
-
-#     # Well it is not possible to use settings.NS.d2rq.join because
-#     # there is a conflict of names with the join function of the Namespace
-#     # class....
-#     tr = list(d2rqGraph.triples((None, URIRef(str(settings.NS.d2rq) + 'join'), None)))
-
-#     def useField((s, p, o)):
-#         if isinstance(o, Literal):
-#             return dbfieldName in o
-#         else:
-#             return False
-#     candidate = filter(useField, tr)
-#     if len(candidate) == 1:
-#         print "Found candidate"
-#         subj = candidate[0][0]
-#         prop = list(d2rqGraph.objects(subj, settings.NS.d2rq.property))
-#         if len(prop) == 1:
-#             return prop[0]
-#         else:
-#             return None
-#     else:
-#         return None
-
 
 
 def rdfGraphAll(model=None):
@@ -713,17 +616,23 @@ def rdfGraphAll(model=None):
         for m in models.get_models():
             if coop.models.StaticURIModel in m.__mro__:
                 for o in m.objects.all():
-                    g += o.toRdfGraph()
+                    try:
+                        g += o.toRdfGraph()
+                    except Exception, e:
+                        log.debug('Unable to create rdf graph for %s, %s' % (o, e))
     else:
         m = models.get_model('coop_local', model)
+        # if m == None:
+        #     m = models.get_model('coop_geo', model)
         if m == None:
-            m = models.get_model('coop_geo', model)
-        if m == None:
-            print _(u"Warning")
-            print _(u"Warning no model found for model name %s" % model)
+            log.debug(_(u"Warning"))
+            log.debug(_(u"Warning no model found for model name %s" % model))
         else:
             for o in m.objects.all():
-                g += o.toRdfGraph()
+                try:
+                    g += o.toRdfGraph()
+                except Exception, e:
+                        log.debug('Unable to create rdf graph for %s, %s' % (o, e))
     return g
 
 
@@ -732,6 +641,7 @@ def rdfDumpAll(destination, format, model=None):
     g.serialize(destination, format=format)
 
 
+
 # It seems to be the best place to do the connection
 # see http://stackoverflow.com/questions/7115097/the-right-place-to-keep-my-signals-py-files-in-django
 # from django.core.signals import  request_finished
