@@ -1,18 +1,12 @@
 # -*- coding:utf-8 -*-
 from django.contrib import admin
-from coop.org.models import BaseEngagement, BaseRelation
-from coop.person.models import BasePerson
-#from coop.exchange.models import BaseExchange, BasePaymentModality, BaseTransaction, BaseProduct
 from django import forms
 from django.conf import settings
 
-# from django.contrib.admin.widgets import FilteredSelectMultiple
 from django.db.models.loading import get_model
 from django.utils.translation import ugettext_lazy as _
 from coop.utils.autocomplete_admin import FkAutocompleteAdmin, InlineAutocompleteAdmin
-
-from coop_local.models import Contact, Person
-from coop_geo.models import Location
+from coop_local.models import Contact, Person, Location
 from django.contrib.contenttypes.models import ContentType
 from django.db.models import Q
 
@@ -22,6 +16,7 @@ from django.utils.safestring import mark_safe
 
 from sorl.thumbnail.admin import AdminImageMixin
 from tinymce.widgets import AdminTinyMCE
+from coop.agenda.admin import DatedInline
 
 from chosen import widgets as chosenwidgets
 
@@ -31,6 +26,9 @@ if "coop.exchange" in settings.INSTALLED_APPS:
 if "coop_geo" in settings.INSTALLED_APPS:
     from coop_geo.admin import LocatedInline, AreaInline
 
+if 'coop.mailing' in settings.INSTALLED_APPS:
+    from coop.mailing.admin import SubscribtionMailingListInline
+
 from django.contrib.contenttypes.generic import GenericTabularInline
 
 
@@ -90,7 +88,8 @@ class OrganizationAdminForm(forms.ModelForm):
 
     class Meta:
         model = get_model('coop_local', 'Organization')
-        widgets = {'category': chosenwidgets.ChosenSelectMultiple()}
+        widgets = {'category': chosenwidgets.ChosenSelectMultiple(),
+                    'sites': chosenwidgets.ChosenSelectMultiple()}
 
     def __init__(self, *args, **kwargs):
         super(OrganizationAdminForm, self).__init__(*args, **kwargs)
@@ -101,9 +100,12 @@ class OrganizationAdminForm(forms.ModelForm):
           | Q(content_type=ContentType.objects.get(model='person'), object_id__in=members_id)
             )
         phone_categories = [1, 2]
-        self.fields['pref_email'].queryset = org_contacts.filter(category=8)
-        self.fields['pref_phone'].queryset = org_contacts.filter(category__in=phone_categories)
+        self.fields['pref_email'].queryset = org_contacts.filter(contact_medium_id=8)
+        self.fields['pref_phone'].queryset = org_contacts.filter(contact_medium_id__in=phone_categories)
         self.fields['category'].help_text = None
+        if 'sites' in self.fields:
+            self.fields['sites'].help_text = None
+
 
         member_locations_id = [m.location.id for m in
             Person.objects.filter(id__in=members_id).exclude(location=None)]  # limit SQL to location field
@@ -154,6 +156,8 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
                     EngagementInline,
                     LocatedInline,
                     ]
+    if "coop.mailing" in settings.INSTALLED_APPS:
+        inlines.append(SubscribtionMailingListInline)
 
     # grace au patch
     # https://code.djangoproject.com/ticket/17856
@@ -175,7 +179,7 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
                         'web']
             }),
         ('Description', {
-            'fields': ['description', 'category',]  # 'tags', )
+            'fields': ['description', 'category',]  # 'tags', ]
             }),
 
         ('Préférences', {
@@ -184,6 +188,10 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
         })
     )
 
+    if settings.COOP_USE_SITES:
+        fieldsets[0][1]['fields'].insert(0, 'sites')
+        list_filter.append('sites')
+
     def get_actions(self, request):
         myactions = dict(create_action(s) for s in get_model('coop_local', 'OrganizationCategory').objects.all())
         return dict(myactions, **super(OrganizationAdmin, self).get_actions(request))  # merging two dicts
@@ -197,3 +205,4 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
     class Media:
         js = ('/static/js/admin_customize.js',)
 
+
