@@ -19,14 +19,13 @@ from django.contrib.sites.models import Site
 import logging
 from urlparse import urlsplit
 
-ADMIN_THUMBS_SIZE = '60x60'
 
 #from mptt.models import MPTTModel, TreeForeignKey
 # class BaseClassification(MPTTModel, URIModel):
 #     label = models.CharField(_(u'label'), max_length=60)
 #     slug = AutoSlugField(populate_from='label', always_update=True, unique=True)
 #     parent = TreeForeignKey('self', null=True, blank=True, related_name='children')
-#     domain_name = 'data.economie-solidaire.fr'
+#     domain_name = 'thess.economie-solidaire.fr'
 
 #     class MPTTMeta:
 #         order_insertion_by = ['label']
@@ -59,7 +58,7 @@ class BaseRoleCategory(models.Model):
 
     def save(self, *args, **kwargs):
         self.save_base()
-        self.uri = u'http://data.economie-solidaire.fr/id/role/%s/' % self.slug
+        self.uri = u'http://thess.economie-solidaire.fr/id/role/%s/' % self.slug
         super(BaseRoleCategory, self).save(*args, **kwargs)
 
     class Meta:
@@ -79,7 +78,7 @@ class BaseRole(URIModel):
     slug = AutoSlugField(populate_from='label', always_update=True, unique=True, editable=False)
     category = models.ForeignKey('coop_local.RoleCategory', null=True, blank=True, verbose_name=_(u'category'))
 
-    domain_name = 'data.economie-solidaire.fr'
+    domain_name = 'thess.economie-solidaire.fr'
 
     class Meta:
         abstract = True
@@ -136,11 +135,8 @@ class BaseRole(URIModel):
 
 DISPLAY = Choices(
     ('PUBLIC',  1,  _(u'public information')),
-    ('USERS',   2,  _(u'registered users')),
-    ('MEMBER',  3,  _(u'members of an organization')),
-    ('RELATED', 4,  _(u'related organizations members')),
-    ('ORG',     5,  _(u'members of this organization')),
-    ('ADMIN',   6,  _(u'administrators of this site')),
+    ('USERS',   2,  _(u'organiztion members')),
+    ('ADMIN',   3,  _(u'administrators of this site')),
 )
 
 COMM_MEANS = Choices(
@@ -222,6 +218,8 @@ class BaseContact(URIModel):
 
 
     # RDF stuff
+    def isOpenData(self):
+        return self.display == DISPLAY.PUBLIC
 
     rdf_type = settings.NS.ess.ContactMedium
 
@@ -242,7 +240,7 @@ class BaseContact(URIModel):
 
 
     def medium_mapping_reverse(self, g, rdfPred, djF, lang=None):
-        values = list(g.objects((rdflib.term.URIRef(self.uri), rdfPred)))        
+        values = list(g.objects(rdflib.term.URIRef(self.uri), rdfPred))        
         values.remove(self.rdf_type)
         m = models.get_model('coop_local', 'contactmedium')
         if len(values) == 1:
@@ -256,6 +254,8 @@ class BaseContact(URIModel):
 class BaseOrgRelationType(models.Model):  # this model will be initialized with a fixture
     label = models.CharField(_(u'label'), max_length=250)
     uri = models.CharField(_(u'URI'), blank=True, max_length=250)
+    org_to_org = models.BooleanField(_('available for org-to-org relations'), default=True)
+    org_to_project = models.BooleanField(_('available for org-to-project relations'), default=True)
 
     def __unicode__(self):
         return self.label
@@ -280,9 +280,10 @@ class BaseRelation(models.Model):
     source = models.ForeignKey('coop_local.Organization', verbose_name=_(u'source organization'), related_name='source')
     target = models.ForeignKey('coop_local.Organization', verbose_name=_(u'target organization'), related_name='target')
     reltype = models.PositiveSmallIntegerField(_(u'Relation type'), choices=RELATIONS.CHOICES, blank=True, null=True)  # TODO erase when data migrated AND remove
-    relation_type = models.ForeignKey('coop_local.OrgRelationType', verbose_name=_(u'relation type'), 
-                                                            null=True, blank=True)      # blank, null = True from the new Fkey
-    
+    relation_type = models.ForeignKey('coop_local.OrgRelationType',
+                                        verbose_name=_(u'relation type'),
+                                        null=True, blank=True)
+
     created = exfields.CreationDateTimeField(_(u'created'), null=True)
     modified = exfields.ModificationDateTimeField(_(u'modified'), null=True)
     #confirmed = models.BooleanField(default=False, verbose_name=_(u'confirmed by the target organization'))
@@ -294,10 +295,11 @@ class BaseRelation(models.Model):
         app_label = 'coop_local'
 
     def __unicode__(self):
-        return u'"' + self.source.__unicode__() + u'"' + \
-            self.relation_type.__unicode__() + \
-            u'"' + self.target.__unicode__() + u'".'
+        return _(u"Relation : %(a)s is a %(r)s of %(b)s") % {'a': self.source.__unicode__(),
+                                                             'r': self.relation_type.__unicode__(),
+                                                             'b': self.target.__unicode__()}
     '''
+    # TODO
     def save(self):
         vérifier si la relation inverse existe
     '''
@@ -311,10 +313,15 @@ class BaseEngagement(URIModel):
     org_admin = models.BooleanField(_(u'has editor rights'), default=True)
     engagement_display = models.PositiveSmallIntegerField(_(u'Display'), choices=DISPLAY.CHOICES, default=DISPLAY.PUBLIC)
 
-    remote_role_uri = models.URLField(_(u'URI'), blank=True, null=True, max_length=250)
-    remote_role_label = models.CharField(blank=True, max_length=100)
+    remote_person_uri = models.URLField(_(u'remote person URI'), blank=True, null=True, max_length=255, editable=False)
+    remote_person_label = models.CharField(_(u'remote person label'),
+                                                max_length=250, blank=True, null=True,
+                                                help_text=_(u'fill this only if the person record is not available locally'))
 
-    remote_organization_uri = models.URLField(_(u'remote organization URI'), blank=True, max_length=255, editable=False)
+    remote_role_uri = models.URLField(_(u'URI'), blank=True, null=True, max_length=250)
+    remote_role_label = models.CharField(blank=True, null=True, max_length=100)
+
+    remote_organization_uri = models.URLField(_(u'remote organization URI'), blank=True, null=True, max_length=255, editable=False)
     remote_organization_label = models.CharField(_(u'remote organization label'),
                                                 max_length=250, blank=True, null=True,
                                                 help_text=_(u'fill this only if the organization record is not available locally'))
@@ -327,24 +334,34 @@ class BaseEngagement(URIModel):
         app_label = 'coop_local'
 
     def __unicode__(self):
-        return '%(person)s, %(role)s @ %(org)s' % {
-                    'person': self.person.__unicode__(),
-                    'role': self.role.__unicode__(),
-                    'org': self.organization.__unicode__()
-                    }
+        if self.role:
+            return '%(person)s, %(role)s @ %(org)s' % {
+                        'person': self.person.__unicode__(),
+                        'role': self.role.__unicode__(),
+                        'org': self.organization.__unicode__()
+                        }
+        else:
+            return '%(person)s, %(role)s @ %(org)s' % {
+                        'person': self.person.__unicode__(),
+                        'role': self.remote_role_label if self.remote_role_label else '',
+                        'org': self.organization.__unicode__()
+                        }
 
     def label(self):
         return self.__unicode__()
 
     # RDF stufs
+    def isOpenData(self):
+        return self.engagement_display == DISPLAY.PUBLIC
+
     rdf_type = settings.NS.org.Membership
     base_mapping = [
         ('single_mapping', (settings.NS.dct.created, 'created'), 'single_reverse'),
         ('single_mapping', (settings.NS.dct.modified, 'modified'), 'single_reverse'),
         ('single_mapping', (settings.NS.org.member, 'person'), 'single_reverse'),
 
-        ('local_or_remote_mapping', (settings.NS.org.organization, 'organization'), 'local_or_remote_mapping'),
-        ('local_or_remote_mapping', (settings.NS.org.role, 'role'), 'local_or_remote_mapping'),
+        ('local_or_remote_mapping', (settings.NS.org.organization, 'organization'), 'local_or_remote_reverse'),
+        ('local_or_remote_mapping', (settings.NS.org.role, 'role'), 'local_or_remote_reverse'),
 
         ('label_mapping', (settings.NS.rdfs.label, 'id', 'fr'), 'label_mapping_reverse'),
 
@@ -357,7 +374,6 @@ class BaseEngagement(URIModel):
         pass
 
 
-
 class BaseOrganizationCategory(models.Model):
     label = models.CharField(blank=True, max_length=100)
     slug = exfields.AutoSlugField(populate_from=('label'), overwrite=True)
@@ -462,7 +478,7 @@ class BaseOrganization(URIModel):
     pref_phone = models.ForeignKey('coop_local.Contact',
                 verbose_name=_(u'preferred phone'),
                 related_name='pref_phone', null=True, blank=True)
-    pref_address = models.ForeignKey('coop_geo.Location',
+    pref_address = models.ForeignKey('coop_local.Location',
                 verbose_name=_(u'preferred postal address'),
                 related_name='pref_adress', null=True, blank=True)
 
@@ -497,11 +513,11 @@ class BaseOrganization(URIModel):
         has_location.short_description = _(u'geo')
 
         def locations(self):
-            from coop_geo.models import Location
+            from coop_local.models import Location
             return Location.objects.filter(id__in=self.located.all().values_list('location_id', flat=True))
 
         def areas(self):
-            from coop_geo.models import Area
+            from coop_local.models import Area
             return Area.objects.filter(id__in=self.framed.all().values_list('location_id', flat=True))
 
         def to_geoJson(self):
@@ -523,11 +539,12 @@ class BaseOrganization(URIModel):
         return self.description != None and len(self.description) > 20
     has_description.boolean = True
     has_description.short_description = _(u'desc.')
+    
 
     def logo_list_display(self):
         try:
             if self.logo:
-                thumb = default.backend.get_thumbnail(self.logo.file, ADMIN_THUMBS_SIZE)
+                thumb = default.backend.get_thumbnail(self.logo.file, settings.ADMIN_THUMBS_SIZE)
                 return '<img width="%s" src="%s" />' % (thumb.width, thumb.url)
             else:
                 return _(u"No Image")
@@ -561,7 +578,10 @@ class BaseOrganization(URIModel):
     #     return ('http://dev.credis.org:8000/org/' + self.slug + '/')
 
     def main_location(self):
-        return self.located.all()[0].location
+        if self.located.all().exists():
+            return self.located.all()[0].location
+        else:
+            return None
 
     def save(self, *args, **kwargs):
         # Set default values for preferred email, phone and postal address
@@ -572,12 +592,12 @@ class BaseOrganization(URIModel):
                 self.pref_phone = fixes[0]
         if self.pref_email == None:
             orgmails = self.contacts.filter(category=8)
-            if orgmails.count() == 1:
+            if orgmails.count() > 0:
                 self.pref_email = orgmails[0]
         if 'coop_geo' in settings.INSTALLED_APPS:
             if self.pref_address == None:
                 locations = self.located.all()  # should we have a "main venue" ?
-                if locations.count() == 1:
+                if locations.count() > 0:
                     self.pref_address = locations[0].location
 
         # TODO move this to Contact model or do it in SQL
@@ -612,8 +632,12 @@ class BaseOrganization(URIModel):
         return self._can_modify_organization(user)
 
     rdf_type = settings.NS.org.Organization
+
+    def isOpenData(self):
+        return self.active
+
     base_mapping = [
-        ('single_mapping', (settings.NS.dct.created, 'created'), 'single_reverse'),
+        ('single_mapping', (settings.NS.dct.created, 'birth'), 'single_reverse'),
         ('single_mapping', (settings.NS.dct.modified, 'modified'), 'single_reverse'),
         ('single_mapping', (settings.NS.legal.legalName, 'title'), 'single_reverse'),
         ('single_mapping', (settings.NS.ov.prefAcronym, 'acronym'), 'single_reverse'),
@@ -627,19 +651,39 @@ class BaseOrganization(URIModel):
         ('single_mapping', (settings.NS.legal.registeredAddress, 'pref_address'), 'single_reverse'),
         ('single_mapping', (settings.NS.skos.note, 'notes'), 'single_reverse'),
 
-        ('multi_mapping', (settings.NS.dct.subject, 'tags'), 'multi_reverse'),
+        ('multi_mapping', (settings.NS.dct.subject, 'tags'), 'multi_reverse'), 
+        # FIXME : Organization objects need to have a primary key value before you can access their tags.
+
         ('multi_mapping', (settings.NS.ess.hasContactMedium, 'contacts'), 'multi_reverse'),
-        ('multi_mapping', (settings.NS.org.hasMember, 'members'), 'multi_reverse'),
+        # FIXME : 'Contact' instance expected
+
+        ('multi_mapping', (settings.NS.org.hasMember, 'members'), 'none_reverse'),
+        # FIXME : 'Organization' instance needs to have a primary key value before a many-to-many relationship can be used.
+
 
         ('logo_mapping', (settings.NS.foaf.logo, 'logo'), 'logo_mapping_reverse'),
         ('prefLabel_mapping', (settings.NS.rdfs.label, 'pref_label'), 'prefLabel_mapping_reverse'),
+    
         ('location_mapping', (settings.NS.locn.location, 'located'), 'location_mapping_reverse'),
+        # FIXME : Located matching query does not exist.
+
         ('location_mapping', (settings.NS.ess.actionArea, 'framed'), 'location_mapping_reverse'),
         ('exchange_mapping', (settings.NS.gr.offers, settings.NS.gr.seeks), 'exchange_mapping_reverse'),
+        ('engagement_mapping', (settings.NS.org.organization, 'engagement_set'), 'engagement_mapping_reverse'),
 
     ]
 
 
+    # We to add in the graph the coresponding Engagement
+    def engagement_mapping(self, rdfPred, djF):
+        res = []
+        for e in getattr(self, djF).all():
+            res.append((rdflib.term.URIRef(e.uri), rdfPred, rdflib.term.URIRef(self.uri)))
+        return res
+
+    def engagement_mapping_reverse(self, g, rdfPred, djF):
+        pass
+
     def location_mapping(self, rdfPred, djF):
         values = map(lambda x: x.location, getattr(self, djF).all())
         return self.multi_mapping_base(values, rdfPred)
@@ -651,10 +695,16 @@ class BaseOrganization(URIModel):
         values = map(coop.models.StaticURIModel.toDjango, rdf_values)
         if djField == 'located':
             m = models.get_model('coop_geo', 'located')
-            values = set(map(lambda x: m.objects.get(object_id=self.id, location=x), values))
+            try:
+                values = set(map(lambda x: m.objects.get(object_id=self.id, location=x), values))
+            except m.DoesNotExist:
+                values = set([])
         elif djField == 'framed':
             m = models.get_model('coop_geo', 'arealink')
-            values = set(map(lambda x: m.objects.get(object_id=self.id, location=x), values))
+            try:
+                values = set(map(lambda x: m.objects.get(object_id=self.id, location=x), values))
+            except m.DoesNotExist:
+                values = set([])
         manager = getattr(self, djField)
         old_values = set(manager.all())
         remove = old_values.difference(values)
@@ -676,6 +726,7 @@ class BaseOrganization(URIModel):
             except ValueError:
                 return []
 
+    # TODO : télécharger le logo dans un dossier /tmp et le passer à sorl.thumbnail pour traitement
     def logo_mapping_reverse(self, g, rdfPred, djF):
         value = list(g.objects(rdflib.term.URIRef(self.uri), rdfPred))
         if len(value) == 1:
@@ -699,7 +750,7 @@ class BaseOrganization(URIModel):
 
     def prefLabel_mapping_reverse(self, g, rdfPred, djF, lang=None):
         value = list(g.objects(rdflib.term.URIRef(self.uri), rdfPred))
-        title = list(g.objects(rdflib.term.URIRef(self.uri), settings.NS.dct.title))
+        title = list(g.objects(rdflib.term.URIRef(self.uri), settings.NS.legal.legalName))
         if value == title:
             setattr(self, 'pref_label', PREFLABEL.TITLE)
         else:
@@ -722,19 +773,36 @@ class BaseOrganization(URIModel):
         values = list(g.objects(rdflib.term.URIRef(self.uri), rdfOffer))
         exchangeModel = models.get_model('coop_local', 'exchange')
         for value in values:
-            ex = exchangeModel.objects.get(uri=str(value))
-            ex.eway = EWAY.OFFER
-            ex.organization = self
-            ex.save()
+            exists = exchangeModel.objects.filter(uri=str(value)).exists()
+            if exists:
+                ex = exchangeModel.objects.get(uri=str(value))
+                ex.eway = EWAY.OFFER
+                ex.organization = self
+                ex.save()
         values = list(g.objects(rdflib.term.URIRef(self.uri), rdfSeek))
         for value in values:
-            ex = exchangeModel.objects.get(uri=str(value))
-            ex.eway = EWAY.NEED
-            ex.organization = self
-            ex.save()
+            exists = exchangeModel.objects.filter(uri=str(value)).exists()
+            if exists:
+                ex = exchangeModel.objects.get(uri=str(value))
+                ex.eway = EWAY.NEED
+                ex.organization = self
+                ex.save()
 
 
+# TODO : use django-multilingual-ng to translate the label field in multiple languages
+# Copied from OrgrelationType, goal is to use the same properties, as Project are Collaborations, a RDF subclass of project
 
+# class BaseCollaborationType(models.Model):  # this model will be initialized with a fixture
+#     label = models.CharField(_(u'label'), max_length=250)
+#     uri = models.CharField(_(u'URI'), blank=True, max_length=250)
+
+#     def __unicode__(self):
+#         return self.label
+
+#     class Meta:
+#         verbose_name = _(u'Collaboration type')
+#         verbose_name_plural = _(u'Collaboration types')
+#         app_label = 'coop_local'
 
 
 
