@@ -4,6 +4,7 @@ from django.shortcuts import render_to_response
 from coop_local.models import Organization, OrganizationCategory, Engagement, Role
 from django.template import RequestContext
 from django.shortcuts import render_to_response, get_object_or_404
+from django.conf import settings
 from coop.org.forms import OrganizationForm, OrganizationCategoryForm
 from django.contrib.auth.decorators import login_required
 from logging import getLogger
@@ -26,7 +27,7 @@ def org_category_detail(request, slug):
 
 def org_detail(request, slug):
     context = {'editable': True}
-    org = get_object_or_404(Organization, slug=slug)
+    org = get_object_or_404(Organization, slug=slug, sites__id=settings.SITE_ID)
     context['organization'] = org
     context['adresses'] = org.located.all()
     context['engagements'] = Engagement.objects.filter(organization=org)
@@ -36,7 +37,7 @@ def org_detail(request, slug):
 @login_required
 def org_edit(request, slug):
     logger = getLogger('default')
-    organization = get_object_or_404(Organization, slug=slug)  # model
+    organization = get_object_or_404(Organization, slug=slug, sites__id=settings.SITE_ID)  # model
     if not request.user.has_perm('can_edit_org', organization):  # model
         raise PermissionDenied
 
@@ -133,7 +134,7 @@ def org_category_edit(request, slug):
 @login_required
 def org_edit_cancel(request, slug):
     """if cancel_edit, delete the preview image"""
-    organization = get_object_or_404(Organization, slug=slug)
+    organization = get_object_or_404(Organization, slug=slug, sites__id=settings.SITE_ID)
     # if organization.temp_logo:
     #     organization.temp_logo = ''
     #     organization.save()
@@ -142,7 +143,7 @@ def org_edit_cancel(request, slug):
 
 @login_required
 def org_category_edit_cancel(request, slug):
-    org_category = get_object_or_404(OrganizationCategory, slug=slug)
+    org_category = get_object_or_404(OrganizationCategory, slug=slug, sites__id=settings.SITE_ID)
     return HttpResponseRedirect(org_category.get_absolute_url())
 
 
