@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 
 from coop.models import StaticURIModel, URI_MODE
-from django.db.models.signals import post_save, post_delete
+from django.db.models.signals import post_save, post_delete, pre_save
 from django.dispatch import receiver
 from django.contrib.sites.models import Site
 from django.conf import  settings
@@ -21,7 +21,7 @@ if getattr(settings, 'SUBHUB_MAINTENANCE_AUTO', False):
     import django_rq
 
 
-log = logging.getLogger('subhub.maintenance')
+log = logging.getLogger('coop')
 
 
 
@@ -60,6 +60,7 @@ def letsCallDistributionTaskProcess(thName):
     subhub.models.DistributionTask.objects.process(log=log)
 
 
+
 # Listener tool
 # The point here is to be careful with synchronization.
 # subhub.publish will create a new DistributionTask object (if no DistributioTask
@@ -68,6 +69,10 @@ def letsCallDistributionTaskProcess(thName):
 # as instance.
 @receiver(post_save)
 def post_save_callback(sender, instance, **kwargs):
+    # Initialize the 'sites' many2many field with the default site
+    if hasattr(instance, 'sites') and not instance.sites.all().exists():
+        instance.sites.add(Site.objects.get_current())
+
     maintenance = getattr(settings, 'SUBHUB_MAINTENANCE_AUTO', False)
     # log.debug(u"Post save callback with sender %s and instance %s and AUTO %s" % (unicode(sender), unicode(instance), maintenance))
 
@@ -78,9 +83,15 @@ def post_save_callback(sender, instance, **kwargs):
             # TODO check if a subscription is done, either lets do it
         elif isinstance(instance, coop_tag.models.TagBase):
             # Subscription done if it does not exists, in other it is simply renew
-            instance.subscribeToUpdades(host=settings.THESAURUS_HOST)
+            if hasattr(settings, 'THESAURUS_HOST') and \
+                    not settings.THESAURUS_HOST == 'http://thess.domain.com':
+                instance.subscribeToUpdades(host=settings.THESAURUS_HOST)
         else:
-            feed_url = 'http://%s/feed/%s/' % (Site.objects.get_current().domain, sender.__name__.lower())
+            domain = Site.objects.get_current().domain
+            if domain.startswith('http'):
+                feed_url = '%s/feed/%s/' % (domain, sender.__name__.lower())
+            else:
+                feed_url = 'http://%s/feed/%s/' % (domain, sender.__name__.lower())
             try:
                 subhub.publish([feed_url], instance.uri, False)
                 #log.debug('publish done; Number of Dist task %s' % len(subhub.models.DistributionTask.objects.all()))
@@ -112,6 +123,24 @@ def post_delete_callback(sender, instance, **kwargs):
     if isinstance(instance, StaticURIModel):
         if instance.uri_mode == URI_MODE.IMPORTED:
             instance.unsubscribeToUpdades()
+        if instance.uri_mode == URI_MODE.LOCAL:
+            from coop_local.models import DeletedURI
+            #peut etre à completer
+            model_name = sender.__name__.lower()
+            deleted = DeletedURI(uri=instance.uri, modified=datetime.datetime.now(),\
+                rdf_type=instance.rdf_type, uuid=instance.uuid, model_name=model_name)
+            deleted.save()
+            domain = Site.objects.get_current().domain
+            if domain.startswith('http'):
+                feed_url = '%s/feed/%s/' % (domain, sender.__name__.lower())
+            else:
+                feed_url = 'http://%s/feed/%s/' % (domain, sender.__name__.lower())
+            try:
+                subhub.publish([feed_url], instance.uri, False)
+                #log.debug('publish done; Number of Dist task %s' % len(subhub.models.DistributionTask.objects.all()))
+            except Exception, e:
+                log.warning(u'Unable to publish %s for feed %s : %s' % (instance, feed_url, e))
+
 
 
 def listener(notification, **kwargs):
@@ -135,7 +164,7 @@ def listener(notification, **kwargs):
     #  build the rdf graph
     g = Graph()
     if model == 'tag':
-        # This is a temporairy work around. data.economie-solidaire.fr is not
+        # This is a temporairy work around. thess.economie-solidaire.fr is not
         # yet responding. TODO we have to deal with contexts as tags come thesaurus
         try:
             # TEMP hard coded
