@@ -32,5 +32,11 @@ if "coop_tag" in settings.INSTALLED_APPS:
         t.contribute_to_class(Exchange, "tags")
     if "coop.agenda" in settings.INSTALLED_APPS:
         t.contribute_to_class(Event, "tags")
+    if "coop.mailing" in settings.INSTALLED_APPS:
+        t.contribute_to_class(MailingList, "tags")
+    if "coop.project" in settings.INSTALLED_APPS:
+        t.contribute_to_class(Project, "tags")
+
+
 
 
