@@ -1,16 +1,15 @@
 # -*- coding:utf-8 -*-
 
 from django.shortcuts import render_to_response, redirect
-from coop_local.models import Organization, OrganizationCategory, Person
-from coop_geo.models import Location, Area, AreaType
+from coop_local.models import Organization, OrganizationCategory, Person, Location, Area
+from coop_geo.models import AreaType
+from django.shortcuts import render_to_response
+from coop_local.models import Organization, OrganizationCategory, DeletedURI
 from django.template import RequestContext
-from django.core.urlresolvers import reverse
 from django.conf import settings
-from django.http import Http404
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 import json
-from coop.models import rdfGraphAll
 from django.core.exceptions import ImproperlyConfigured
 
 if('coop.exchange' in settings.INSTALLED_APPS):
@@ -71,24 +70,17 @@ RDF_SERIALIZATIONS = {
 }
 
 
+
+
 # smallest data API ever
 def get_rdf(request, model, uuid, format):
     req_model = get_model(urimodels[model], model)
-    object = get_object_or_404(req_model, uuid=uuid)
-    return HttpResponse(object.toRdf(format), mimetype=RDF_SERIALIZATIONS[format])
-
-
-def rdfdump(request, model, format):
-    if model == 'all':
-        g = rdfGraphAll()
-    else:
-        g = rdfGraphAll(model)
-    if format == 'ttl':
-        return HttpResponse(g.serialize(format='n3'), mimetype=RDF_SERIALIZATIONS[format])
-    elif format == 'json':
-        return HttpResponse(g.serialize(format='json-ld'), mimetype=RDF_SERIALIZATIONS[format])
-    elif format in RDF_SERIALIZATIONS:
-        return HttpResponse(g.serialize(format=format), mimetype=RDF_SERIALIZATIONS[format])
+    try:
+        object = req_model.objects.get(uuid=uuid)
+        return HttpResponse(object.toRdf(format), mimetype=RDF_SERIALIZATIONS[format])
+    except req_model.DoesNotExist:
+        object = get_object_or_404(DeletedURI, uuid=uuid)
+        return HttpResponse(object.toRdf(format), mimetype=RDF_SERIALIZATIONS[format])
 
 
 def SentryHandler500(request):
@@ -217,3 +209,33 @@ def geojson(request):
     result = {"type": "FeatureCollection", "features":  res}
     return HttpResponse(json.dumps(result), mimetype="application/json")
 
+
+
+
+if 'haystack' in settings.INSTALLED_APPS:
+    from haystack.views import SearchView
+    from coop_local.models import Article
+
+    class ModelSearchView(SearchView):
+        def __name__(self):
+            return "ModelSearchView"
+
+        def extra_context(self):
+            extra = super(ModelSearchView, self).extra_context()
+
+            if self.results == []:
+                extra['org'] = self.form.search().models(Organization)
+                if('coop.exchange' in settings.INSTALLED_APPS):
+                    extra['exchange'] = self.form.search().models(Exchange)
+                extra['article'] = self.form.search().models(Article)
+                if('coop.agenda' in settings.INSTALLED_APPS):
+                    extra['event'] = self.form.search().models(Event)
+            else:
+                extra['org'] = self.results.models(Organization)
+                if('coop.exchange' in settings.INSTALLED_APPS):
+                    extra['exchange'] = self.results.models(Exchange)
+                extra['article'] = self.results.models(Article)
+                if('coop.agenda' in settings.INSTALLED_APPS):
+                    extra['event'] = self.results.models(Event)
+
+            return extra
